@@ -35,6 +35,10 @@ try:
     from inspect import getfullargspec as getargspec  # Python 3.0 and later
 except ImportError:
     from inspect import getargspec
+try:
+    Ellipsis
+except NameError:
+    Ellipsis = None  # was introduced in Python 3.10
 
 
 INF = float('inf')
@@ -50,6 +54,10 @@ try:
     SEQUENCE = Sequence, np.ndarray
 except ImportError:
     SEQUENCE = Sequence
+try:
+    Ellipsis
+except NameError:
+    Ellipsis = None  # was introduced in Python 3.10
 
 
 class BaseColumn(OrderedState):
@@ -63,24 +71,64 @@ class BaseColumn(OrderedState):
     default_value = u''
     ndim = 1
 
-    def __init__(self, datamatrix):
+    def __init__(self, datamatrix, rowid=None, seq=None, metadata=None):
 
         """
         desc:
             Constructor.
 
         arguments:
-            datamatrix:	A DataMatrix object.
+            datamatrix: A DataMatrix object.
+            
+        keywords:
+            rowid:
+                type: [Index, None]
+                desc: A rowid index to initialize the column with. If None,
+                      a new index is created.
+            seq:
+                type: [Sequence, None]
+                desc: Data to initialize the column with. If None, a new
+                      sequence is created.
+            metadata:
+                desc: Any Python object that should be associated with this
+                      column as metadata.
         """
 
         # Global import like this avoid cyclical imports
         global DataMatrix
         from datamatrix import DataMatrix
 
+        if not isinstance(datamatrix, DataMatrix):
+            raise TypeError('expecting DataMatrix, not {}'.format(datamatrix))
         self._datamatrix = datamatrix
         self._typechecking = True
-        self._init_rowid()
-        self._init_seq()
+        self.metadata = metadata
+        if rowid is None:
+            self._init_rowid()
+        else:
+            self._rowid = rowid
+        if seq is None:
+            self._init_seq()
+        else:
+            self._seq = seq
+    
+    @property
+    def loaded(self):
+        """
+        name: loaded
+
+        desc:
+            A property to unloaded the column to disk (by assigning `False`)
+            and load the column from disk (by assigning `True`). You don't
+            usually change this property manually, but rather let the built-in
+            memory management decide when and columns need to be (un)loaded.
+        """
+        return True
+    
+    @loaded.setter
+    def loaded(self, value):
+        if not value:
+            raise NotImplementedError('this column cannot be unloaded')
 
     def equals(self, other):
         
@@ -148,7 +196,7 @@ class BaseColumn(OrderedState):
 
         n = self._numbers
         if len(n) == 0:
-            return NAN
+            return CallableFloat(NAN)
         return CallableFloat(sum(n) / len(n))
 
     @property
@@ -165,10 +213,10 @@ class BaseColumn(OrderedState):
 
         n = sorted(self._numbers)
         if len(n) == 0:
-            return NAN
+            return CallableFloat(NAN)
         i = int(len(n)/2)
         if len(n) % 2 == 1:
-            return n[i]
+            return CallableFloat(n[i])
         return CallableFloat(.5*n[i]+.5*n[i-1])
 
     @property
@@ -186,7 +234,7 @@ class BaseColumn(OrderedState):
         m = self.mean
         n = self._numbers
         if len(n) <= 1:
-            return NAN
+            return CallableFloat(NAN)
         return CallableFloat(math.sqrt(sum((i-m)**2 for i in n)/(len(n)-1)))
 
     @property
@@ -202,7 +250,7 @@ class BaseColumn(OrderedState):
 
         n = self._numbers
         if not len(n):
-            return NAN
+            return CallableFloat(NAN)
         return CallableFloat(max(n))
 
     @property
@@ -234,7 +282,7 @@ class BaseColumn(OrderedState):
 
         n = self._numbers
         if not len(n):
-            return NAN
+            return CallableFloat(NAN)
         return CallableFloat(sum(n))
 
     @property
@@ -398,9 +446,7 @@ class BaseColumn(OrderedState):
             type: BaseColumn
         """
 
-        col = self._empty_col()
-        col._rowid = Index(_rowid)
-        col._seq = [None] * len(_rowid)
+        col = self._empty_col(rowid=Index(_rowid), seq=[None] * len(_rowid))
         self_row_id = set(self._rowid)
         for i, row in enumerate(_rowid):
             col._seq[i] = (
@@ -480,10 +526,25 @@ class BaseColumn(OrderedState):
             BaseColunn
         """
 
-        col = self._empty_col()
-        col._rowid = self._rowid[key]
-        col._seq = self._seq[key]
-        return col
+        return self._empty_col(rowid=self._rowid[key], seq=self._seq[key])
+
+    def _getellipsiskey(self, key):
+
+        """
+        visible: False
+
+        desc:
+            Gets the average.
+
+        arguments:
+            key:	A slice object.
+
+        returns:
+            BaseColunn
+        """
+
+        return self.mean
+
 
     def _getsequencekey(self, key):
 
@@ -500,13 +561,12 @@ class BaseColumn(OrderedState):
             BaseColunn
         """
 
-        col = self._empty_col()
-        col._rowid = Index()
-        col._seq = []
+        rowid = Index()
+        seq = []
         for i in key:
-            col._rowid.append(self._rowid[i])
-            col._seq.append(self._seq[i])
-        return col
+            rowid.append(self._rowid[i])
+            seq.append(self._seq[i])
+        return self._empty_col(rowid=rowid, seq=seq)
 
     def _getdatamatrixkey(self, key):
 
@@ -538,12 +598,9 @@ class BaseColumn(OrderedState):
         returns:
             BaseColunn
         """
-
-        col = self._empty_col()
-        col._rowid = key
-        col._seq = [self._seq[self._rowid.index(_rowid)] for _rowid in key]
-        return col
-
+        seq = [self._seq[self._rowid.index(_rowid)] for _rowid in key]
+        return self._empty_col(rowid=key, seq=seq)
+        
     def _sortedrowid(self):
 
         """
@@ -785,8 +842,7 @@ class BaseColumn(OrderedState):
             A modified column.
         """
 
-        col = self._empty_col()
-        col._rowid = self._rowid.copy()
+        col = self._empty_col(rowid=self._rowid.copy())
         for i, (_other, val) in enumerate(
             zip(self._seq, self._tosequence(other, len(self)))
             if flip else
@@ -803,12 +859,11 @@ class BaseColumn(OrderedState):
 
     def _map(self, fnc):
 
-        col = self._empty_col()
-        col._rowid = self._rowid.copy()
-        col._seq = [fnc(val) for val in self._seq]
-        return col
+        return self._empty_col(rowid=self._rowid.copy(),
+                               seq=[fnc(val) for val in self._seq])
 
-    def _empty_col(self, datamatrix=None):
+
+    def _empty_col(self, datamatrix=None, **kwargs):
 
         """
         visible: False
@@ -826,14 +881,14 @@ class BaseColumn(OrderedState):
             BaseColumn
         """
 
-        if datamatrix:
-            return self.__class__(datamatrix)
+        if datamatrix is not None:
+            return self.__class__(datamatrix, **kwargs)
         # If this column results from slicing from an original column, the
         # rowids do not match with the DataMatrix. In that case, create a new
         # DataMatrix for the empty column.
         if len(self) != len(self._datamatrix):
-            return self.__class__(DataMatrix(length=len(self)))
-        return self.__class__(self._datamatrix)
+            return self.__class__(DataMatrix(length=len(self)), **kwargs)
+        return self.__class__(self._datamatrix, **kwargs)
 
     def _nanorinf(self, val):
 
@@ -896,7 +951,7 @@ class BaseColumn(OrderedState):
 
     def __len__(self):
 
-        return len(self._seq)
+        return len(self._rowid)
 
     def __getitem__(self, key):
 
@@ -904,6 +959,8 @@ class BaseColumn(OrderedState):
             return self._getintkey(key)
         if isinstance(key, slice):
             return self._getslicekey(key)
+        if Ellipsis is not None and key == Ellipsis:
+            return self._getellipsiskey(key)
         if isinstance(key, SEQUENCE):
             # Hack for matplotlib
             if self._requests_new_axis(key):
@@ -919,6 +976,8 @@ class BaseColumn(OrderedState):
             self._setintkey(key, value)
         elif isinstance(key, slice):
             self._setslicekey(key, value)
+        elif Ellipsis is not None and key == Ellipsis:
+            self._setslicekey(slice(None), value)
         elif isinstance(key, SEQUENCE):
             self._setsequencekey(key, value)
         elif isinstance(key, DataMatrix):
